@@ -12,7 +12,7 @@ use File::Temp;
 use File::Which;
 use POSIX qw(SIGTERM SIGKILL WNOHANG setuid);
 
-our $VERSION = '1.20_02';
+our $VERSION = '1.20_03';
 our $errstr;
 
 # Various paths that Postgres gets installed under, sometimes with a version on the end,
@@ -149,6 +149,9 @@ has _owner_pid => (
 );
 
 method BUILD($) {
+    # Ensure we have one or the other ways of starting Postgres:
+    try { $self->pg_ctl or $self->postmaster } catch { die $_ };
+
     if (! defined $self->uid && $ENV{USER} && $ENV{USER} eq 'root') {
         my @a = getpwnam('nobody')
             or die "user nobody does not exist, use uid() to specify user: $!";
